/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
*/

cordova.define("pastry-plugin-moduleRouter.moduleRouter", function(require, exports, module) {
var exec = require('cordova/exec');

var moduleRouter = {
    /**
     * 发送给原生端 “模块路由” 完成的消息
     * 发送给原生端通道建立成功的消息。原生端的startRouterChannel()方法处理该消息。（注意：需要在deviceready消息之后）
     */
    startRouterChannel:function(routeListening) {
        console.log('moduleRouter模块路由 启动（JS端）');
        exec(function(data) {
            console.log('moduleRouter模块路由启动（JS端）接收 客户端信息 data = ' + JSON.stringify(data));
            routeListening(data);
        }, null, "moduleRouter", "startRouterChannel", []);
    },
    exitModule:function(data) {
        console.log('moduleRouter模块路由 退出模块应用（JS端）');
        exec(null, null, "moduleRouter", "exitModule", [data]);
    },
    closeModule:function() {
        console.log('closeModule Vue模块路由 退出模块应用（JS端）');
        exec(null, null, "moduleRouter", "closeModule", []);
    },

    /**
     * 提供给JS端的app应用层监听路由跳转消息。js端app应用层接收到该消息，并进行处理。（注意：跳转前清空之前的路由信息）
     */
    // routeListening:function() {
        
    // },
    /**
     * 停止WebView所在的主页面的模块路由，但是不关闭WebView。（不清空WebView所在的主页面）
     */
    stopRouterChannel:function() {
        console.log('moduleRouter模块路由 停止（JS端）');
        exec(null, null, "moduleRouter", "stopRouterChannel", []);
    },
    /**
     * 关闭WebView所在的主页面。（清空WebView所在的主页面）
     * 关闭当前业务的模块，并发送给原生端消息，原生端的closeRouterChannel()方法处理该消息。
     */
    closeRouterChannel:function() {
        console.log('moduleRouter模块路由 关闭（JS端）');
        exec(null, null, "moduleRouter", "closeRouterChannel", []);
    },
    /**
     * 监听原生端发送的 通信请求 信息
     * 监听插件通信信息。JS端接收到关于路由的信息后，通过routeListening方法发送给app应用层。
     */
    // channelCommunicating:function() {

    // }
};

module.exports = moduleRouter;

});
